==> 1.0.1.tar.gz: lib/uibit/KTab.dart <==
import 'dart:async';

import '../uibit.dart';

enum KTabType { normal, chip, text }

class KTab extends StatefulWidget {
  final ValueChanged<int> onChange;
  final List<String> items;
  final int selected;
  final KTabType type;
  final double height;
  final PubSub<int> pubsub;

  const KTab({Key key, this.onChange, this.items, this.selected = 0, this.type = KTabType.normal, this.height, this.pubsub}) : super(key: key);

  @override
  _KTabState createState() => _KTabState();
}

class _KTabState extends State<KTab> {
  int selected = 0;

  List<String> get items => widget.items ?? [];

  KTabType get type => widget.type ?? KTabType.normal;


  @override
  void initState() {
    selected = widget.selected ?? 0;
    widget.pubsub?.puber(puber);
    super.initState();
  }

  puber(page) {
    print("publisher:$page");
    setState(() {
      selected = page;
    });
  }

  @override
  void dispose() {
    widget.pubsub?.puber(null);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: widget.height ?? 50,
      child: ListView(
        scrollDirection: Axis.horizontal,
        children: _children(),
      ),
    );
  }

  bool isSelected(int index) {
    return selected == index;
  }

  String getText(int index) {
    return items[index];
  }

  Widget item(int index) {
    return InkWell(
      borderRadius: kRadius.all,
      onTap: () => _onTap(index),
      child: _item(index),
    );
  }

  TextStyle _textStyle(bool selected) {
    switch (type) {
      case KTabType.normal:
        return selected ? KTextStyle.tabBold : KTextStyle.tabNormal;
      case KTabType.chip:
        return selected ? KTextStyle.chipBold : KTextStyle.chipNormal.copyWith(color: kColor.opa(0.7));
      case KTabType.text:
        return selected ? KTextStyle.tabBold : KTextStyle.tabNormal.copyWith(fontWeight: FontWeight.w300);
    }
    return selected ? KTextStyle.bold : KTextStyle.normal;
  }

  List<Widget> _children() {
    final children = <Widget>[];
    int i = 0;
    items.forEach((element) {
      children.add(Container(
        alignment: Alignment.center,
        padding: EdgeInsets.only(right: kSize.edge),
        margin: EdgeInsets.only(right: kSize.edge),
        child: item(i),
      ));
      i++;
    });
    return children;
  }

  Widget _item(int index) {
    final text = Text(
      getText(index),
      style: _textStyle(isSelected(index)),
    );
    dynamic parent = text;
    switch (type) {
      case KTabType.normal:
        parent = Container(
          color: Colors.transparent,
          padding: kEdge.vertical.copyWith(right: kSize.edgeBig),
          child: CustomPaint(
            painter: KTabPainter(selected: isSelected(index), type: type),
            child: text,
          ),
        );
        break;
      case KTabType.chip:
        parent = Container(
          padding: kEdge.chip,
          decoration: BoxDecoration(
            color: isSelected(index) ? kColor.dopacity(0.1) : kColor.opa(0.1),
            borderRadius: kRadius.all,
          ),
          child: text,
        );
        break;
      case KTabType.text:
        parent = text;
        break;
    }
    return parent;
  }

  void _onTap(int index) {
    setState(() {
      selected = index;
    });
    widget.pubsub?.pub(index);
  }
}

class KTabPainter extends CustomPainter {
  final bool selected;
  final KTabType type;

  KTabPainter({this.selected, this.type});

  @override
  void paint(Canvas canvas, Size size) {
    final p = Paint();
    p.style = PaintingStyle.fill;
    p.color = selected ? kColor.light() : kColor.none;
    canvas.drawCircle(Offset(size.width / 2, size.height + 5), 2.5, p);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return oldDelegate != this;
  }
}

==> 1.0.2.tar.gz: lib/uibit/KTab.dart <==
import 'dart:async';

import '../uibit.dart';

enum KTabType { normal, chip, text }

class KTab extends StatefulWidget {
  final ValueChanged<int> onChange;
  final List<String> items;
  final int selected;
  final KTabType type;
  final double height;
  final PubSub<int> pubsub;

  const KTab({Key key, this.onChange, this.items, this.selected = 0, this.type = KTabType.normal, this.height, this.pubsub}) : super(key: key);

  @override
  _KTabState createState() => _KTabState();
}

class _KTabState extends State<KTab> {
  int selected = 0;

  List<String> get items => widget.items ?? [];

  KTabType get type => widget.type ?? KTabType.normal;


  @override
  void initState() {
    selected = widget.selected ?? 0;
    widget.pubsub?.puber(puber);
    super.initState();
  }

  puber(page) {
    print("publisher:$page");
    setState(() {
      selected = page;
    });
  }

  @override
  void dispose() {
    widget.pubsub?.puber(null);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: widget.height ?? 50,
      child: ListView(
        scrollDirection: Axis.horizontal,
        children: _children(),
      ),
    );
  }

  bool isSelected(int index) {
    return selected == index;
  }

  String getText(int index) {
    return items[index];
  }

  Widget item(int index) {
    return InkWell(
      borderRadius: kRadius.all,
      onTap: () => _onTap(index),
      child: _item(index),
    );
  }

  TextStyle _textStyle(bool selected) {
    switch (type) {
      case KTabType.normal:
        return selected ? KTextStyle.tabBold : KTextStyle.tabNormal;
      case KTabType.chip:
        return selected ? KTextStyle.chipBold : KTextStyle.chipNormal.copyWith(color: kColor.opa(0.7));
      case KTabType.text:
        return selected ? KTextStyle.tabBold : KTextStyle.tabNormal.copyWith(fontWeight: FontWeight.w300);
    }
    return selected ? KTextStyle.bold : KTextStyle.normal;
  }

  List<Widget> _children() {
    final children = <Widget>[];
    int i = 0;
    items.forEach((element) {
      children.add(Container(
        alignment: Alignment.center,
        padding: EdgeInsets.only(right: kSize.edge),
        margin: EdgeInsets.only(right: kSize.edge),
        child: item(i),
      ));
      i++;
    });
    return children;
  }

  Widget _item(int index) {
    final text = Text(
      getText(index),
      style: _textStyle(isSelected(index)),
    );
    dynamic parent = text;
    switch (type) {
      case KTabType.normal:
        parent = Container(
          color: Colors.transparent,
          padding: kEdge.vertical.copyWith(right: kSize.edgeBig),
          child: CustomPaint(
            painter: KTabPainter(selected: isSelected(index), type: type),
            child: text,
          ),
        );
        break;
      case KTabType.chip:
        parent = Container(
          padding: kEdge.chip,
          decoration: BoxDecoration(
            color: isSelected(index) ? kColor.dopa(0.1) : kColor.opa(0.1),
            borderRadius: kRadius.all,
          ),
          child: text,
        );
        break;
      case KTabType.text:
        parent = text;
        break;
    }
    return parent;
  }

  void _onTap(int index) {
    setState(() {
      selected = index;
    });
    widget.pubsub?.pub(index);
  }
}

class KTabPainter extends CustomPainter {
  final bool selected;
  final KTabType type;

  KTabPainter({this.selected, this.type});

  @override
  void paint(Canvas canvas, Size size) {
    final p = Paint();
    p.style = PaintingStyle.fill;
    p.color = selected ? kColor.light() : kColor.none;
    canvas.drawCircle(Offset(size.width / 2, size.height + 5), 2.5, p);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return oldDelegate != this;
  }
}
